===================
Bing Ads Python SDK
===================

.. image:: https://img.shields.io/pypi/v/bingads.svg
        :target: https://pypi.python.org/pypi/bingads


The Bing Ads Python Software Development Kit (SDK) Version 13.0 enhances the experience of developing Bing Ads applications
with the Python programming language.
The SDK includes proxy classes for all Bing Ads API web services and abstracts the low level details of authentication with OAuth.
You can also read and write bulk files with the SDK BulkFileReader and BulkFileWriter,
and use the high level BulkServiceManager interface to abstract and execute operations in the low level Bulk API.
For more information, see `Bing Ads Client Libraries <https://docs.microsoft.com/en-us/bingads/guides/client-libraries>`_.

Getting Started
---------------

To get started developing Bing Ads applications with Python, 
install the SDK and either start with the `examples <https://github.com/BingAds/BingAds-Python-SDK/tree/master/examples>`_ or follow one of the application walkthroughs.
For more information, see `Getting Started Using Python with Bing Ads Services <https://docs.microsoft.com/en-us/bingads/guides/get-started-python>`_.

External Dependencies
---------------------

    - `suds-community <https://pypi.org/pypi/suds-community>`_
    
    - `requests <http://pypi.python.org/pypi/requests>`_
    
    - `enum34 <http://pypi.python.org/pypi/enum34>`_